==> certbot-dns-baidu-0.1.0.tar.gz: certbot-dns-baidu-0.1.0/setup.py <==
import sys

from setuptools import setup
from setuptools import find_packages


version = '0.1.0'

# Remember to update local-oldest-requirements.txt when changing the minimum
# acme/certbot version.
install_requires = [
    'acme>=0.21.1',
    'certbot>=0.21.1',
    'dns-lexicon',
    'mock',
    'setuptools',
    'zope.interface',
]

# read the contents of your README file
from os import path

this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, "README.md")) as f:
    long_description = f.read()
long_description_content_type="text/markdown"

setup(
    name='certbot-dns-baidu',
    version=version,
    description="Baidu DNS Authenticator plugin for Certbot",
    url='https://github.com/chaoers/certbot-dns-baidu',
    author="Asterisk",
    author_email='fanguofan@asteriscum.cn',
    license='GNU General Public License v3.0',
    python_requires='>=3.4',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Plugins',
        'Intended Audience :: System Administrators',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Security',
        'Topic :: System :: Installation/Setup',
        'Topic :: System :: Networking',
        'Topic :: System :: Systems Administration',
        'Topic :: Utilities',
    ],

    packages=find_packages(),
    include_package_data=True,
    install_requires=install_requires,
    entry_points={
        'certbot.plugins': [
            'dns-baidu = certbot_dns_baidu.dns_baidu:Authenticator',
        ],
    },
    test_suite='certbot_dns_baidu',
)

==> certbot-dns-baidu-0.1.1.tar.gz: certbot-dns-baidu-0.1.1/setup.py <==
import sys

from setuptools import setup
from setuptools import find_packages


version = '0.1.1'

# Remember to update local-oldest-requirements.txt when changing the minimum
# acme/certbot version.
install_requires = [
    'acme>=0.21.1',
    'certbot>=0.21.1',
    'dns-lexicon',
    'mock',
    'setuptools',
    'zope.interface',
]

# read the contents of your README file
from os import path

this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, "README.md")) as f:
    long_description = f.read()

setup(
    name='certbot-dns-baidu',
    version=version,
    description="Baidu DNS Authenticator plugin for Certbot",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url='https://github.com/chaoers/certbot-dns-baidu',
    author="Asterisk",
    author_email='fanguofan@asteriscum.cn',
    license='GNU General Public License v3.0',
    python_requires='>=3.4',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Plugins',
        'Intended Audience :: System Administrators',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Security',
        'Topic :: System :: Installation/Setup',
        'Topic :: System :: Networking',
        'Topic :: System :: Systems Administration',
        'Topic :: Utilities',
    ],

    packages=find_packages(),
    include_package_data=True,
    install_requires=install_requires,
    entry_points={
        'certbot.plugins': [
            'dns-baidu = certbot_dns_baidu.dns_baidu:Authenticator',
        ],
    },
    test_suite='certbot_dns_baidu',
)
